%%% LaTeX class for manuscripts submitted to the
%%% Berkeley Electronic Journals (BEPress)
%%%
%%% author: Christopher Carroll
%%% version: 1.1 (May 25 2009)
%%% license: LaTeX Project Public License 
%%%
%%% Modified from style itaxpf by Arne Henningsen
%%% version: 1.0 (09 July 2007)
%%% license: LaTeX Project Public License 
%%%
%%% Note: This is an unofficial style file that may not fully comply
%%% with the Formatting Instructions of the BEPress Journals
%%% in every detail.
%%% Further information is available at
%%% http://www.uni-kiel.de/agrarpol/ahenningsen/latex-bibtex.html
%%%
%%% This document class is based on the "scrartcl" class
%%% from the KOMA script bundle.  For documentation, Google KOMA-Script Documentation
%%%
%%% The following additional packages are required:
%%% amsmath, babel, csquotes, endfloat, endnotes, fontenc, geometry,
%%% ifthen, lmodern, natbib, setspace, url
%%%
%%% The corresponding BibTeX style file "bejournal.bst" should be used
%%% for the bibliography: \bibliographystyle{bejournal}
%%%
%%% This class provides 2 options:
%%% titlepage = include a title page (with command "\maketitle")
%%% noendfloat = do not move "floats" (tables and figures) to the end
%%%
%%% This document class provides 4 new commands:
%%% \keywords can be used to show keywords below the abstract
%%% \jelclass can be used to show JEL classifications below the abstract
%%% \affiliation can be used specify the affiliation(s) of the author(s)
%%%    (only shown if option "titlepage" is used)
%%% \address can be used to specify the address of the corresponding author
%%%    (only shown if option "titlepage" is used)
%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{bejournal}[2009/05/23 LaTeX class for the Berkeley Electronic Journals]

\RequirePackage{ifthen}

% permit double spacing
\RequirePackage{setspace}
%\doublespacing

% option to place floats not at the end
\newcounter{UseEndfloat}
\setcounter{UseEndfloat}{1}
\DeclareOption{noendfloat}{\setcounter{UseEndfloat}{0}}

% option to include a title page
\newcounter{IncludeTitlePage}
\setcounter{IncludeTitlePage}{0}
\DeclareOption{titlepage}{\setcounter{IncludeTitlePage}{1}}

% pass any options on to the scrartcl class and load this class with some options
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrartcl}}
\ProcessOptions\relax
\LoadClass[fontsize=12pt,english,numbers=noenddot,captions=tableheading,captions=nooneline]{scrartcl}
% pointlessnumbers = do not add final dot after ordinary section numbers
% tablecaptionabove = use \captionabove for captions above rather than below tables
% noonelinecaption = do not treat one-line captions differently

% use new TeX encoding scheme (T1), which contains accented (European) letters,
% to make European hyphenations work
\RequirePackage[T1]{fontenc}

% use babel package and set language to english
\RequirePackage[english]{babel}

% page format, margins
\RequirePackage{geometry}
\geometry{letterpaper, tmargin=1.4in, bmargin=1.4in, lmargin=1.4in,
  rmargin=1.4in, headheight=0in, headsep=0in, footskip=0.5in }

% spacing around formulas
\AtBeginDocument{
\setlength{\abovedisplayshortskip}{6pt}
\setlength{\belowdisplayshortskip}{6pt}
\setlength{\abovedisplayskip}{6pt}
\setlength{\belowdisplayskip}{6pt}
\allowdisplaybreaks
}

% Don't indent the second and later lines of footnotes
\deffootnote[1em]{0.0em}{1em}{\textsuperscript{\thefootnotemark}}

% spacing around captions and floats
\setlength{\abovecaptionskip}{6pt}
\setlength{\belowcaptionskip}{3pt}
\setlength{\floatsep}{0pt}
\setlength{\textfloatsep}{20pt}
\setlength{\intextsep}{15pt}

\RequirePackage{cancel,verbatim,
amsmath,amssymb,amsfonts,
dcolumn,multicol,latexsym
,ifthen
,afterpage
,Endnotes
,moreverb
,bm        % Allow bold math
,bbm       % Blackbord math
,hhline    % Allow double hlines
,tipa      % Define more characters, in particular the \textthorn character
,booktabs
,color
}
\RequirePackage[mathscr]{eucal}
\RequirePackage[normalem]{ulem}

% font for URLs
\RequirePackage{url}
\def\UrlFont{\ttfamily}

%% formatting section headers
\setkomafont{section}{\normalfont \Large \bfseries}
\setkomafont{subsection}{\normalfont \large}
\setkomafont{subsubsection}{\normalfont \itshape}

% citations and bibliography
\RequirePackage[authoryear]{natbib}
\AtBeginDocument{\renewcommand{\refname}{\clearpage References}}

% captions of figures and tables
\setcapwidth[c]{\textwidth}
% \setcapindent*{0pt}
\setkomafont{captionlabel}{\centering \bfseries}
\setkomafont{caption}{\centering}
\renewcommand{\captionformat}{~ }

% move floats to the end of the paper
\ifthenelse{\equal{\theUseEndfloat}{1}}{
   \RequirePackage[noheads,nolists,tablesfirst,nomarkers]{endfloat}
   \renewcommand{\efloatseparator}{\mbox{}} 
   \renewcommand{\figureplace}{%
      \begin{center}
      [\figurename~\thepostfig\ here]
      \end{center}
   }
   \renewcommand{\tableplace}{%
      \begin{center}
      [\tablename~\theposttbl\ here]
      \end{center}
   }
}{}

% titlepage with title, author(s), and date
\newcommand{\affiliationA}[1]{\newcommand{\@affiliationA}{#1}}
\newcommand{\affiliationB}[1]{\newcommand{\@affiliationB}{#1}}
\newcommand{\affiliationC}[1]{\newcommand{\@affiliationC}{#1}}
\newcommand{\affiliationD}[1]{\newcommand{\@affiliationD}{#1}}
\newcommand{\affiliationE}[1]{\newcommand{\@affiliationE}{#1}}
%\newcommand{\address2}[1]{\newcommand{\@address2}{#1}}
%\newcommand{\address3}[1]{\newcommand{\@address3}{#1}}
%\newcommand{\address4}[1]{\newcommand{\@address4}{#1}}
%\newcommand{\address5}[1]{\newcommand{\@address5}{#1}}

\newcommand{\authorAmark}{\textsuperscript{a}}
\newcommand{\authorBmark}{\textsuperscript{b}}
\newcommand{\authorCmark}{\textsuperscript{c}}
\newcommand{\authorDmark}{\textsuperscript{d}}
\newcommand{\authorEmark}{\textsuperscript{e}}

\newcommand{\authorAinfo}{\noindent{\makebox[0pt][r]{\textsuperscript{a}}\footnotesize}}
\newcommand{\authorBinfo}{\noindent{\makebox[0pt][r]{\textsuperscript{b}}\footnotesize}}
\newcommand{\authorCinfo}{\noindent{\makebox[0pt][r]{\textsuperscript{c}}\footnotesize}}
\newcommand{\authorDinfo}{\noindent{\makebox[0pt][r]{\textsuperscript{d}}\footnotesize}}
\newcommand{\authorEinfo}{\noindent{\makebox[0pt][r]{\textsuperscript{e}}\footnotesize}}

\renewcommand{\maketitle}{
   \ifthenelse{\equal{\theIncludeTitlePage}{1}}{
      \thispagestyle{empty}
      \vspace*{1mm}
   }{}
   \enlargethispage{1000pt} 
   \begin{center}
   \begin{LARGE}
   \begin{spacing}{1.25}
   \textbf{\@title}
   \end{spacing}
   \end{LARGE}
   \vspace*{5mm}
   \ifthenelse{\equal{\theIncludeTitlePage}{1}}{
      \vspace*{7mm}
      \@author\\
      \vspace{0.75cm}\today 
      \ifthenelse{ \isundefined\@affiliation }{}{
         \vspace*{5mm}
         \textit{\@affiliation}\\
      }
      \vspace*{0.25cm}
      \ifthenelse{ \isundefined\@address }{}{
         \vspace*{10mm}
         \begin{spacing}{1}
         \@address\\
         \end{spacing}
      }
      \vspace*{1mm}
   }{}
   \end{center}
}

% abstract, keywords, JEL classification
\newcommand{\titleWithNoLineBreaks}[1]{\newcommand{\@titleWithNoLineBreaks}{#1}}
\newcommand{\keywords}[1]{\newcommand{\@keywords}{#1}}
\newcommand{\jelclass}[1]{\newcommand{\@jelclass}{#1}}

\renewenvironment{abstract}{%
   \begin{spacing}{1.0}
   \noindent {\tiny \phantom{.}} \\ % Trick to get proper spacing 
   \noindent \hrule 
   \vspace*{5mm}
   \noindent \textbf{Abstract}\\
   \indent
}{%
   \ifthenelse{ \isundefined\@keywords }{
   \ClassWarningNoLine{bejournal}{No keywords specified.
      Please use the command \protect\keywords}
   }{
   }
   \noindent {\tiny \phantom{.}} \\  % Trick to get proper spacing 
\noindent \hrule
   \vspace*{5mm}
   \end{spacing}

\medskip \noindent
\textbf{Keywords~} \@keywords
\ifthenelse{ \isundefined\@jelclass }{
\ClassWarningNoLine{bejournal}{No JEL classification specified.
   Please use the command \protect\jelclass}
}{
\noindent

\noindent \textbf{JEL classification~} \@jelclass
}
}

% avoid clubs and widows
\clubpenalty=300  % penalty for breaking a page with only one sentence; set to 10000 to prohibit
%\widowpenalty=10000
% \displaywidowpenalty=10000

\hbadness 2000  % LaTeX default is 1000, which is too finicky - set to 10000 to get rid of complaints

% increase stretchability of the spaces (avoid overful hboxes)
\setlength{\emergencystretch}{3em}


\pagestyle{plain}
\thispagestyle{empty}

\newcommand{\titlepagefinish}{\normalsize\newpage}
